<?php
/*
  Plugin Name: WP Slider Forms
  Description: This plugin contains the functionality to add, update, delete banners from the admin panel and show as sliders in the front end with links to specific form. When members submit the form they will be listed in admin panel under this plugin menu. Admin can see or delete the members from the list.
  Plugin URI: http://www.jolshiri.com/
  Author URI: http://www.jolshiri.com/
  Author: Jolshiri Software Solution
  Version: 1.1

  Copyright (c) 2002-2013 by A K M Mainul Islam
  Copyright (c) 2012 Jolshiri Software Solution

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//Stop direct call
if(preg_match('#' . basename(__FILE__) . '#', $_SERVER['PHP_SELF']))
{
    die('You are not allowed to call this page directly.');
}

define('JSS_SF_PLUGIN_URL', plugin_dir_url(__FILE__));

global $jss_sf_db_version;

$jss_sf_db_version = '1.1'; // version changed from 1.0 to 1.1
/**
 * register_activation_hook implementation
 *
 * will be called when user activates plugin first time
 * must create needed database tables
 */

function jss_sf_install()
{
    global $wpdb;
    global $jss_sf_db_version;

    $table_name_banners = $wpdb->prefix . 'jss_sf_banners'; // do not forget about tables prefix
    $table_name_members = $wpdb->prefix . 'jss_sf_members'; // do not forget about tables prefix


    $sql_banners = "CREATE TABLE " . $table_name_banners . " (
        id int(11) NOT NULL AUTO_INCREMENT,
        title varchar(100) DEFAULT NULL,
        description text,
        banner varchar(255) DEFAULT NULL,
        is_active int(1) DEFAULT NULL,
        created_at datetime DEFAULT NULL,
        PRIMARY KEY  (id)
      )";

    $sql_members = "CREATE TABLE " . $table_name_members . " (
        id int(11) NOT NULL AUTO_INCREMENT,
        first_name varchar(100) DEFAULT NULL,
        last_name varchar(100) DEFAULT NULL,
        email varchar(100) DEFAULT NULL,
        banner_id int(11) DEFAULT NULL,
        banner_title varchar(100) DEFAULT NULL,
        is_mail_sent int(1) DEFAULT '0',
        created_at datetime DEFAULT NULL,
        PRIMARY KEY  (id)
      );";

    // we do not execute sql directly
    // we are calling dbDelta which cant migrate database
    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql_banners);
    dbDelta($sql_members);


    // save current database version for later use (on upgrade)
    add_option('jss_sf_db_version', $jss_sf_db_version);

    /**
     * [OPTIONAL] Example of updating to 1.1 version
     *
     * If you develop new version of plugin
     * just increment $jss_sf_db_version variable
     * and add following block of code
     *
     * must be repeated for each new version
     * in version 1.1 we change email field
     * to contain 200 chars rather 100 in version 1.0
     * and again we are not executing sql
     * we are using dbDelta to migrate table changes
     */
    $installed_ver = get_option('jss_sf_db_version');
    if($installed_ver != $jss_sf_db_version)
    {
        // notice that we are updating option, rather than adding it
        update_option('jss_sf_db_version', $jss_sf_db_version);
    }
}

register_activation_hook(__FILE__, 'jss_sf_install');

/**
 * register_activation_hook implementation
 *
 * [OPTIONAL]
 * additional implementation of register_activation_hook
 * to insert some dummy data
 */
function jss_sf_install_data()
{
    global $wpdb;

    $table_name_banners = $wpdb->prefix . 'jss_sf_banners'; // do not forget about tables prefix

    $wpdb->insert($table_name_banners, array(
        'title' => 'Consumers Guide to Medicaid Planning',
        'description' => 'Consumers Guide to Medicaid Planning',
        'banner' => ''
    ));
}

register_activation_hook(__FILE__, 'jss_sf_install_data');

/**
 * Trick to update plugin database, see docs
 */
function jss_sf_update_db_check()
{
    global $jss_sf_db_version;
    if(get_site_option('jss_sf_db_version') != $jss_sf_db_version)
    {
        jss_sf_install();
    }
}

add_action('plugins_loaded', 'jss_sf_update_db_check');

function jss_sf_deactivate()
{
    
}

//register_deactivation_hook( __FILE__, 'jss_sf_deactivate' );

require_once 'jss_sf_banners.php';
require_once 'jss_sf_members.php';


/**
 * PART 3. Admin page
 * ============================================================================
 *
 * In this part you are going to add admin page for custom table
 *
 * http://codex.wordpress.org/Administration_Menus
 */

/**
 * admin_menu hook implementation, will add pages to list persons and to add new one
 */
function jss_sf_admin_menu()
{
    add_menu_page(__('Jss_sf', 'jss_sf'), __('Jss_sf', 'jss_sf'), 'activate_plugins', 'banners', 'jss_sf_banners_page_handler');
    add_submenu_page('banners', __('Banners', 'jss_sf'), __('Banners', 'jss_sf'), 'activate_plugins', 'banners', 'jss_sf_banners_page_handler');
    // add new will be described in next part
    add_submenu_page('banners', __('Add Banner', 'jss_sf'), __('Add Banner', 'jss_sf'), 'activate_plugins', 'banners_form', 'jss_sf_banners_form_page_handler');
    add_submenu_page('banners', __('Members', 'jss_sf'), __('Members', 'jss_sf'), 'activate_plugins', 'members', 'jss_sf_members_page_handler');
    add_submenu_page('banners', __('Instructions', 'jss_sf'), __('Instructions', 'jss_sf'), 'activate_plugins', 'instructions', 'jss_sf_instructions_page_handler');
}

add_action('admin_menu', 'jss_sf_admin_menu');

/**
 * Do not forget about translating your plugin, use __('english string', 'your_uniq_plugin_name') to retrieve translated string
 * and _e('english string', 'your_uniq_plugin_name') to echo it
 * in this example plugin your_uniq_plugin_name == jss_sf
 *
 * to create translation file, use poedit FileNew catalog...
 * Fill name of project, add "." to path (ENSURE that it was added - must be in list)
 * and on last tab add "__" and "_e"
 *
 * Name your file like this: [my_plugin]-[ru_RU].po
 *
 * http://codex.wordpress.org/Writing_a_Plugin#Internationalizing_Your_Plugin
 * http://codex.wordpress.org/I18n_for_WordPress_Developers
 */
function jss_sf_languages()
{
    load_plugin_textdomain('jss_sf', false, dirname(plugin_basename(__FILE__)));
}

add_action('init', 'jss_sf_languages');

function jss_sf_get_image_tag($image_name)
{
    $upload_dir = wp_upload_dir();
    $upload_dir_url = $upload_dir['baseurl'];
    ?>
    <img src="<?php echo $upload_dir_url . '/jss_sf_banners/' . $image_name; ?>" alt="Banner" /><br/> 
    <?php
}

require_once 'shortcodes.php';
require_once 'instructions.php';